@@ -32,6 +32,9 @@ import re
 pattern = re.compile(r"""(?P<propertyName>(?=^)\w[\s\w,]+)(?(1):)(?:\s|\n)?(?P<propertyData>[\W\w\s]+)""", re.MULTILINE)
 f_pattern = re.compile(r"""(?P<propertyName>(?=^)\w[\s\w,]+)(?(1):)""", re.MULTILINE)
 
+DEFAULT_BRANCH = "$/Philips.PIC/PIIC iX/Main"
+CURRENT_BRANCH = DEFAULT_BRANCH
+
 logHandler = handlers.RotatingFileHandler('tfs.log', maxBytes=20 * 1024 * 1024, backupCount=10)
 logging.basicConfig(
     level=logging.DEBUG,
@@ -96,7 +99,6 @@ else:
     #quit()
 
 
-
 DirectoryPath = path
 
 TFPath = os.getenv('AGENT_HOMEDIRECTORY')
@@ -362,7 +364,6 @@ def get_last_branch_changeSet(branch, numberOfChangets):
 
     changeSetList = []
 
-    # output = output.replace("\r", "")
     output_list = [item.lstrip() for item in output.split("-" * 79 + endline_char) if item]
 
     idx = 0
@@ -371,7 +372,7 @@ def get_last_branch_changeSet(branch, numberOfChangets):
         changeSetDict = {}
         itemsDict = {}
 
-        changeSetDict['branch'] = 'branch'
+        changeSetDict['branch'] = branch
         changeSetDict['items'] = itemsDict
 
         changeset_info_items = list()
@@ -460,6 +461,7 @@ def get_last_branch_changeSet(branch, numberOfChangets):
 
                     changeSetDict['items'] = itemsDict
 
+        changeSetDict['branch'] = branch
         changeSetList.append(changeSetDict)
 
     return changeSetList
@@ -486,7 +488,10 @@ def get_file_tree(basePath=""):
     def getAllFileNames(path, basePath=""):
         for dirname, dirnames, filenames in os.walk(path):
             for filename in filenames:
-                allFileNames.append(basePath + filename)
+                try:
+                    allFileNames.append(basePath + filename)
+                except MemoryError:
+                    break
 
             if '$tf' in dirnames:
                 # don't go into any $tf directories.
@@ -499,7 +504,10 @@ def get_file_tree(basePath=""):
                 })
 
     for row in directories:
-        getAllFileNames(row['directory'], row['basePath'])
+        try:
+            getAllFileNames(row['directory'], row['basePath'])
+        except MemoryError:
+            break
 
     return allFileNames
 
@@ -738,7 +746,7 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
         },
         'ref_type': 'commit',
         'after': "",
-        'ref': '',
+        'ref': CURRENT_BRANCH,
         'base_ref': '',
         'before': commits[length - 1]['sha']
     }
@@ -765,7 +773,7 @@ def wrap_shelvet_push_event(arr, info):
         },
         'ref_type': 'commit',
         'after': "",
-        'ref': '',
+        'ref': CURRENT_BRANCH,
         'base_ref': '',
         'before': ''
     }
@@ -809,7 +817,7 @@ def wrap_shelvet_push_event(arr, info):
         "renamed": [x for x in files if "rename" in x["status"]],
         "parents": [],
         "date": info["Date"],
-        "branches": [],
+        "branches": [CURRENT_BRANCH],
         "message": info["Comment"],
         "file_tree": [x["filename"] for x in files]
     }
@@ -867,6 +875,7 @@ def slugify(value):
 
 
 def performSync(branch, shelvet, force=False, isBlameRequired=True, shouldRunRestApi=False, numberOfChangets=None):
+    logging.info("Define branch: {} / {} / {}".format(branch, CURRENT_BRANCH, DEFAULT_BRANCH))
     import time
     start_time = time.time()
 
@@ -939,7 +948,7 @@ def appsurifytfs(*args):
         blame = True
         numberOfChangets = None
         shouldRunRestApi = False
-        branch = ''
+        branch = DEFAULT_BRANCH
         shelvet = ''
 
         if '-f' in sys.argv:
@@ -954,6 +963,8 @@ def appsurifytfs(*args):
         if '-branch' in sys.argv:
             index = sys.argv.index('-branch')
             branch = sys.argv[index + 1]
+            global CURRENT_BRANCH
+            CURRENT_BRANCH = branch
         if '-shelvet' in sys.argv:
             index = sys.argv.index('-shelvet')
             shelvet = sys.argv[index + 1]
