@@ -81,7 +81,7 @@ def detect_endline(text):
 def get_last_branch_changeSet(branch, numberOfChangets):
     # output = execute(MoveToMainDirectory + TF_Branches_History.format(branch) + (
     #     "" if numberOfChangets == None else " /stopafter:{}".format(numberOfChangets)))
-    commandLine = "cat ./mock-output-new.txt"
+    commandLine = "cat ./mock-output-lf.txt"
     output = execute(commandLine)
 
     endline_char = detect_endline(output)
@@ -146,21 +146,35 @@ def get_last_branch_changeSet(branch, numberOfChangets):
                         filename = filename.lstrip().rstrip()
 
                         if ',' in action:
-                            actions = action.split(', ')
-                            if all(s in actions for s in ('delete', 'source rename')):
-                                action = 'delete'
-                            if all(s in actions for s in ('delete', 'rollback')):
-                                action = 'delete'
-                            elif all(s in actions for s in ('encoding', 'edit')):
-                                action = 'edit'
-                            elif all(s in actions for s in ('merge', 'edit')):
-                                action = 'edit'
-                            elif all(s in actions for s in ('edit', 'rollback')):
-                                action = 'edit'
-                            elif all(s in actions for s in ('rename', 'edit')):
-                                action = 'rename'
-                            elif all(s in actions for s in ('add', 'source rename')):
-                                action = 'add'
+                            # actions = action.split(', ')
+                            # if all(s in actions for s in ('delete', 'source rename')):
+                            #     action = 'delete'
+                            # if all(s in actions for s in ('delete', 'rollback')):
+                            #     action = 'delete'
+                            # elif all(s in actions for s in ('encoding', 'edit')):
+                            #     action = 'edit'
+                            # elif all(s in actions for s in ('merge', 'edit')):
+                            #     action = 'edit'
+                            # elif all(s in actions for s in ('edit', 'rollback')):
+                            #     action = 'edit'
+                            # elif all(s in actions for s in ('rename', 'edit')):
+                            #     action = 'rename'
+                            # elif all(s in actions for s in ('add', 'source rename')):
+                            #     action = 'add'
+                            if action.startswith("add"):
+                                action = "add"
+                            elif action.startswith("delete"):
+                                action = "delete"
+                            elif action.startswith("edit"):
+                                action = "edit"
+                            elif action.startswith("rename"):
+                                action = "edit"
+                            elif action.startswith("merge"):
+                                action = "edit"
+                            elif action.startswith("encoding"):
+                                action = "edit"
+                            else:
+                                action = "edit"
 
                         if action not in itemsDict:
                             itemsDict[action] = [filename, ]
@@ -206,7 +220,8 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
                 if all(s in keys for s in ('delete', 'source rename')):
                     key = 'delete'
                 else:
-                    raise Exception("Handle multiple keys")
+                    # raise Exception("Handle multiple keys")
+                    key = 'edit'
 
             status = ''
 
